ValidCashtagRegexExtension extension
- on
Properties
- cashBoundary → String
-
Available on RegExpMatch, provided by the ValidCashtagRegexExtension extension
The text matched immediately before the$mark, mirroringValidHashtagRegexExtension.boundarybut renamed to avoid clashing with the hashtag extension when both are imported in the same scope.no setter - cashMark → String
-
Available on RegExpMatch, provided by the ValidCashtagRegexExtension extension
no setter - symbol → String
-
Available on RegExpMatch, provided by the ValidCashtagRegexExtension extension
no setter